@@ -53,12 +53,13 @@ class VadeRealtimeAPI:
         header = {"apiKey": self.api_key}
         resp = requests.get(url, headers=header)
         try:
-            if resp.status_code != 200 or resp.status_code != 201:
+            if resp.status_code == 200 or resp.status_code == 201:
+                resp_obj = json.loads(resp.text)
+                new_spot = VadeSpotRealtime.from_json(resp_obj)
+                if new_spot:
+                    return new_spot
+            else:
                 return None
-            resp_obj = json.loads(resp.text)
-            new_spot = VadeSpotRealtime.from_json(resp_obj)
-            if new_spot:
-                return new_spot
         except Exception as e:
             print("Error getSpotOccupancy: {}".format(resp.text))
             return None
